summaryrefslogtreecommitdiffstats
path: root/Graphics/GraphicsEngineD3D11
diff options
context:
space:
mode:
authorEgor Yusov <egor.yusov@gmail.com>2019-03-05 06:38:04 +0000
committerEgor Yusov <egor.yusov@gmail.com>2019-03-05 06:38:04 +0000
commitf551f6353eaf4efe9b7f26d48822b96ebb0706a0 (patch)
tree8d9f6fdb24bcacbdbc04d29f02fbe0a8a7b1f7c3 /Graphics/GraphicsEngineD3D11
parentCompleted D3D12 back-end refactor to comply with the new API (diff)
downloadDiligentCore-f551f6353eaf4efe9b7f26d48822b96ebb0706a0.tar.gz
DiligentCore-f551f6353eaf4efe9b7f26d48822b96ebb0706a0.zip
Updated D3D11, D3D12, and Vk EngineFactory headers & structures
Diffstat (limited to 'Graphics/GraphicsEngineD3D11')
-rw-r--r--Graphics/GraphicsEngineD3D11/CMakeLists.txt5
-rwxr-xr-xGraphics/GraphicsEngineD3D11/include/DeviceContextD3D11Impl.h12
-rw-r--r--Graphics/GraphicsEngineD3D11/include/RenderDeviceD3D11Impl.h13
-rw-r--r--Graphics/GraphicsEngineD3D11/interface/EngineD3D11Attribs.h70
-rw-r--r--Graphics/GraphicsEngineD3D11/interface/EngineFactoryD3D11.h (renamed from Graphics/GraphicsEngineD3D11/interface/RenderDeviceFactoryD3D11.h)22
-rw-r--r--Graphics/GraphicsEngineD3D11/readme.md2
-rwxr-xr-xGraphics/GraphicsEngineD3D11/src/DeviceContextD3D11Impl.cpp13
-rw-r--r--Graphics/GraphicsEngineD3D11/src/EngineFactoryD3D11.cpp (renamed from Graphics/GraphicsEngineD3D11/src/RenderDeviceFactoryD3D11.cpp)100
-rw-r--r--Graphics/GraphicsEngineD3D11/src/RenderDeviceD3D11Impl.cpp10
9 files changed, 86 insertions, 161 deletions
diff --git a/Graphics/GraphicsEngineD3D11/CMakeLists.txt b/Graphics/GraphicsEngineD3D11/CMakeLists.txt
index b263d602..f54fa680 100644
--- a/Graphics/GraphicsEngineD3D11/CMakeLists.txt
+++ b/Graphics/GraphicsEngineD3D11/CMakeLists.txt
@@ -34,11 +34,10 @@ set(INTERFACE
interface/BufferD3D11.h
interface/BufferViewD3D11.h
interface/DeviceContextD3D11.h
- interface/EngineD3D11Attribs.h
+ interface/EngineFactoryD3D11.h
interface/FenceD3D11.h
interface/PipelineStateD3D11.h
interface/RenderDeviceD3D11.h
- interface/RenderDeviceFactoryD3D11.h
interface/SamplerD3D11.h
interface/ShaderD3D11.h
interface/ShaderResourceBindingD3D11.h
@@ -54,11 +53,11 @@ set(SRC
src/CommandListD3D11Impl.cpp
src/D3D11TypeConversions.cpp
src/DeviceContextD3D11Impl.cpp
+ src/EngineFactoryD3D11.cpp
src/FenceD3D11Impl.cpp
src/GUIDDef.cpp
src/PipelineStateD3D11Impl.cpp
src/RenderDeviceD3D11Impl.cpp
- src/RenderDeviceFactoryD3D11.cpp
src/SamplerD3D11Impl.cpp
src/ShaderD3D11Impl.cpp
src/ShaderResourceBindingD3D11Impl.cpp
diff --git a/Graphics/GraphicsEngineD3D11/include/DeviceContextD3D11Impl.h b/Graphics/GraphicsEngineD3D11/include/DeviceContextD3D11Impl.h
index d9a0e44d..01a54eeb 100755
--- a/Graphics/GraphicsEngineD3D11/include/DeviceContextD3D11Impl.h
+++ b/Graphics/GraphicsEngineD3D11/include/DeviceContextD3D11Impl.h
@@ -53,12 +53,12 @@ class DeviceContextD3D11Impl final : public DeviceContextBase<IDeviceContextD3D1
public:
using TDeviceContextBase = DeviceContextBase<IDeviceContextD3D11, DeviceContextD3D11ImplTraits>;
- DeviceContextD3D11Impl(IReferenceCounters* pRefCounters,
- IMemoryAllocator& Allocator,
- IRenderDevice* pDevice,
- ID3D11DeviceContext* pd3d11DeviceContext,
- const struct EngineD3D11Attribs& EngineAttribs,
- bool bIsDeferred);
+ DeviceContextD3D11Impl(IReferenceCounters* pRefCounters,
+ IMemoryAllocator& Allocator,
+ IRenderDevice* pDevice,
+ ID3D11DeviceContext* pd3d11DeviceContext,
+ const struct EngineD3D11CreateInfo& EngineAttribs,
+ bool bIsDeferred);
virtual void QueryInterface(const INTERFACE_ID& IID, IObject** ppInterface)override final;
virtual void SetPipelineState(IPipelineState* pPipelineState)override final;
diff --git a/Graphics/GraphicsEngineD3D11/include/RenderDeviceD3D11Impl.h b/Graphics/GraphicsEngineD3D11/include/RenderDeviceD3D11Impl.h
index 87189352..b325554f 100644
--- a/Graphics/GraphicsEngineD3D11/include/RenderDeviceD3D11Impl.h
+++ b/Graphics/GraphicsEngineD3D11/include/RenderDeviceD3D11Impl.h
@@ -29,7 +29,6 @@
#include "RenderDeviceD3D11.h"
#include "RenderDeviceD3DBase.h"
#include "DeviceContextD3D11.h"
-#include "EngineD3D11Attribs.h"
namespace Diligent
{
@@ -40,11 +39,11 @@ class RenderDeviceD3D11Impl final : public RenderDeviceD3DBase<IRenderDeviceD3D1
public:
using TRenderDeviceBase = RenderDeviceD3DBase<IRenderDeviceD3D11>;
- RenderDeviceD3D11Impl( IReferenceCounters* pRefCounters,
- IMemoryAllocator& RawMemAllocator,
- const EngineD3D11Attribs& EngineAttribs,
- ID3D11Device* pd3d11Device,
- Uint32 NumDeferredContexts );
+ RenderDeviceD3D11Impl( IReferenceCounters* pRefCounters,
+ IMemoryAllocator& RawMemAllocator,
+ const EngineD3D11CreateInfo& EngineAttribs,
+ ID3D11Device* pd3d11Device,
+ Uint32 NumDeferredContexts );
virtual void QueryInterface(const INTERFACE_ID& IID, IObject** ppInterface)override final;
virtual void CreateBuffer(const BufferDesc& BuffDesc, const BufferData* pBuffData, IBuffer** ppBuffer)override final;
@@ -74,7 +73,7 @@ public:
private:
virtual void TestTextureFormat( TEXTURE_FORMAT TexFormat )override final;
- EngineD3D11Attribs m_EngineAttribs;
+ EngineD3D11CreateInfo m_EngineAttribs;
/// D3D11 device
CComPtr<ID3D11Device> m_pd3d11Device;
diff --git a/Graphics/GraphicsEngineD3D11/interface/EngineD3D11Attribs.h b/Graphics/GraphicsEngineD3D11/interface/EngineD3D11Attribs.h
deleted file mode 100644
index a5208ef5..00000000
--- a/Graphics/GraphicsEngineD3D11/interface/EngineD3D11Attribs.h
+++ /dev/null
@@ -1,70 +0,0 @@
-/* Copyright 2015-2019 Egor Yusov
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF ANY PROPRIETARY RIGHTS.
- *
- * In no event and under no legal theory, whether in tort (including negligence),
- * contract, or otherwise, unless required by applicable law (such as deliberate
- * and grossly negligent acts) or agreed to in writing, shall any Contributor be
- * liable for any damages, including any direct, indirect, special, incidental,
- * or consequential damages of any character arising as a result of this License or
- * out of the use or inability to use the software (including but not limited to damages
- * for loss of goodwill, work stoppage, computer failure or malfunction, or any and
- * all other commercial damages or losses), even if such Contributor has been advised
- * of the possibility of such damages.
- */
-
-#pragma once
-
-/// \file
-/// Definition of the Engine D3D11 attribs
-
-#include "../../GraphicsEngine/interface/GraphicsTypes.h"
-
-namespace Diligent
-{
- /// Debug flags that can be specified when creating Direct3D11-based engine implementation.
- ///
- /// \sa CreateDeviceAndContextsD3D11Type, CreateSwapChainD3D11Type, LoadGraphicsEngineD3D11
- enum class EngineD3D11DebugFlags : Uint32
- {
- /// Before executing draw/dispatch command, verify that
- /// all required shader resources are bound to the device context
- VerifyCommittedShaderResources = 0x01,
-
- /// Verify that all committed cotext resources are relevant,
- /// i.e. they are consistent with the committed resource cache.
- /// This is very expensive operation and should generally not be
- /// necessary.
- VerifyCommittedResourceRelevance = 0x02
- };
-
- /// Attributes of the Direct3D11-based engine implementation
- struct EngineD3D11Attribs : public EngineCreationAttribs
- {
- static constexpr Uint32 DefaultAdapterId = 0xFFFFFFFF;
-
- /// Id of the hardware adapter the engine should be initialized on
- Uint32 AdapterId = DefaultAdapterId;
-
- /// Debug flags. See Diligent::EngineD3D11DebugFlags for a list of allowed values.
- ///
- /// \sa CreateDeviceAndContextsD3D11Type, CreateSwapChainD3D11Type, LoadGraphicsEngineD3D11
- Uint32 DebugFlags;
-
- EngineD3D11Attribs() :
- DebugFlags(0)
- {
- #ifdef _DEBUG
- DebugFlags = static_cast<Uint32>(EngineD3D11DebugFlags::VerifyCommittedShaderResources);
- #endif
- }
- };
-}
diff --git a/Graphics/GraphicsEngineD3D11/interface/RenderDeviceFactoryD3D11.h b/Graphics/GraphicsEngineD3D11/interface/EngineFactoryD3D11.h
index a4dd8476..dceab777 100644
--- a/Graphics/GraphicsEngineD3D11/interface/RenderDeviceFactoryD3D11.h
+++ b/Graphics/GraphicsEngineD3D11/interface/EngineFactoryD3D11.h
@@ -36,18 +36,16 @@
# include "../../../Common/interface/StringTools.h"
#endif
-#include "EngineD3D11Attribs.h"
-
namespace Diligent
{
class IEngineFactoryD3D11
{
public:
- virtual void CreateDeviceAndContextsD3D11( const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts ) = 0;
+ virtual void CreateDeviceAndContextsD3D11(const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts ) = 0;
virtual void CreateSwapChainD3D11( IRenderDevice* pDevice,
IDeviceContext* pImmediateContext,
@@ -56,12 +54,12 @@ public:
void* pNativeWndHandle,
ISwapChain** ppSwapChain ) = 0;
- virtual void AttachToD3D11Device(void* pd3d11NativeDevice,
- void* pd3d11ImmediateContext,
- const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts) = 0;
+ virtual void AttachToD3D11Device(void* pd3d11NativeDevice,
+ void* pd3d11ImmediateContext,
+ const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts) = 0;
virtual void EnumerateHardwareAdapters(Uint32& NumAdapters,
HardwareAdapterAttribs* Adapters) = 0;
diff --git a/Graphics/GraphicsEngineD3D11/readme.md b/Graphics/GraphicsEngineD3D11/readme.md
index 3a9dab60..121d4a49 100644
--- a/Graphics/GraphicsEngineD3D11/readme.md
+++ b/Graphics/GraphicsEngineD3D11/readme.md
@@ -8,7 +8,7 @@ Implementation of Direct3D11 back-end
The following code snippet shows how to initialize Diligent Engine in D3D11 mode.
```cpp
-#include "RenderDeviceFactoryD3D11.h"
+#include "EngineFactoryD3D11.h"
using namespace Diligent;
// ...
diff --git a/Graphics/GraphicsEngineD3D11/src/DeviceContextD3D11Impl.cpp b/Graphics/GraphicsEngineD3D11/src/DeviceContextD3D11Impl.cpp
index f531ab9a..f177586d 100755
--- a/Graphics/GraphicsEngineD3D11/src/DeviceContextD3D11Impl.cpp
+++ b/Graphics/GraphicsEngineD3D11/src/DeviceContextD3D11Impl.cpp
@@ -34,7 +34,6 @@
#include "PipelineStateD3D11Impl.h"
#include "SwapChainD3D11.h"
#include "ShaderResourceBindingD3D11Impl.h"
-#include "EngineD3D11Attribs.h"
#include "EngineD3D11Defines.h"
#include "CommandListD3D11Impl.h"
#include "RenderDeviceD3D11Impl.h"
@@ -42,12 +41,12 @@
namespace Diligent
{
- DeviceContextD3D11Impl::DeviceContextD3D11Impl( IReferenceCounters* pRefCounters,
- IMemoryAllocator& Allocator,
- IRenderDevice* pDevice,
- ID3D11DeviceContext* pd3d11DeviceContext,
- const struct EngineD3D11Attribs& EngineAttribs,
- bool bIsDeferred ) :
+ DeviceContextD3D11Impl::DeviceContextD3D11Impl( IReferenceCounters* pRefCounters,
+ IMemoryAllocator& Allocator,
+ IRenderDevice* pDevice,
+ ID3D11DeviceContext* pd3d11DeviceContext,
+ const struct EngineD3D11CreateInfo& EngineAttribs,
+ bool bIsDeferred ) :
TDeviceContextBase(pRefCounters, pDevice, bIsDeferred),
m_pd3d11DeviceContext( pd3d11DeviceContext ),
m_DebugFlags(EngineAttribs.DebugFlags),
diff --git a/Graphics/GraphicsEngineD3D11/src/RenderDeviceD3D11Impl.cpp b/Graphics/GraphicsEngineD3D11/src/RenderDeviceD3D11Impl.cpp
index 86eae24a..04f54ad5 100644
--- a/Graphics/GraphicsEngineD3D11/src/RenderDeviceD3D11Impl.cpp
+++ b/Graphics/GraphicsEngineD3D11/src/RenderDeviceD3D11Impl.cpp
@@ -40,11 +40,11 @@
namespace Diligent
{
-RenderDeviceD3D11Impl :: RenderDeviceD3D11Impl(IReferenceCounters* pRefCounters,
- IMemoryAllocator& RawMemAllocator,
- const EngineD3D11Attribs& EngineAttribs,
- ID3D11Device* pd3d11Device,
- Uint32 NumDeferredContexts) :
+RenderDeviceD3D11Impl :: RenderDeviceD3D11Impl(IReferenceCounters* pRefCounters,
+ IMemoryAllocator& RawMemAllocator,
+ const EngineD3D11CreateInfo& EngineAttribs,
+ ID3D11Device* pd3d11Device,
+ Uint32 NumDeferredContexts) :
TRenderDeviceBase
{
pRefCounters,
diff --git a/Graphics/GraphicsEngineD3D11/src/RenderDeviceFactoryD3D11.cpp b/Graphics/GraphicsEngineD3D11/src/EngineFactoryD3D11.cpp
index 7e5ff13f..d69a94ee 100644
--- a/Graphics/GraphicsEngineD3D11/src/RenderDeviceFactoryD3D11.cpp
+++ b/Graphics/GraphicsEngineD3D11/src/EngineFactoryD3D11.cpp
@@ -25,7 +25,7 @@
/// Routines that initialize D3D11-based engine implementation
#include "pch.h"
-#include "RenderDeviceFactoryD3D11.h"
+#include "EngineFactoryD3D11.h"
#include "RenderDeviceD3D11Impl.h"
#include "DeviceContextD3D11Impl.h"
#include "SwapChainD3D11Impl.h"
@@ -48,24 +48,24 @@ public:
return &TheFactory;
}
- void CreateDeviceAndContextsD3D11( const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts )override final;
-
- void CreateSwapChainD3D11( IRenderDevice* pDevice,
- IDeviceContext* pImmediateContext,
- const SwapChainDesc& SCDesc,
- const FullScreenModeDesc& FSDesc,
- void* pNativeWndHandle,
- ISwapChain** ppSwapChain )override final;
-
- void AttachToD3D11Device(void* pd3d11NativeDevice,
- void* pd3d11ImmediateContext,
- const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts)override final;
+ void CreateDeviceAndContextsD3D11(const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts)override final;
+
+ void CreateSwapChainD3D11(IRenderDevice* pDevice,
+ IDeviceContext* pImmediateContext,
+ const SwapChainDesc& SCDesc,
+ const FullScreenModeDesc& FSDesc,
+ void* pNativeWndHandle,
+ ISwapChain** ppSwapChain)override final;
+
+ void AttachToD3D11Device(void* pd3d11NativeDevice,
+ void* pd3d11ImmediateContext,
+ const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts)override final;
};
@@ -92,7 +92,7 @@ inline bool SdkLayersAvailable()
/// Creates render device and device contexts for Direct3D11-based engine implementation
/// \param [in] EngineAttribs - Engine creation attributes.
/// \param [out] ppDevice - Address of the memory location where pointer to
/// the created device will be written
/// \param [out] ppContexts - Address of the memory location where pointers to
@@ -103,13 +103,13 @@ inline bool SdkLayersAvailable()
/// of deferred contexts is requested, pointers to the
/// contexts are written to ppContexts array starting
/// at position 1
-void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts )
+void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11(const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts )
{
- if (EngineAttribs.DebugMessageCallback != nullptr)
- SetDebugMessageCallback(EngineAttribs.DebugMessageCallback);
+ if (EngineCI.DebugMessageCallback != nullptr)
+ SetDebugMessageCallback(EngineCI.DebugMessageCallback);
VERIFY( ppDevice && ppContexts, "Null pointer provided" );
if( !ppDevice || !ppContexts )
@@ -153,14 +153,14 @@ void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attr
CComPtr<ID3D11DeviceContext> pd3d11Context;
CComPtr<IDXGIAdapter1> hardwareAdapter;
- if(EngineAttribs.AdapterId != EngineD3D11Attribs::DefaultAdapterId)
+ if (EngineCI.AdapterId != EngineD3D11CreateInfo::DefaultAdapterId)
{
auto Adapters = FindCompatibleAdapters();
- if (EngineAttribs.AdapterId < Adapters.size())
- hardwareAdapter = Adapters[EngineAttribs.AdapterId];
+ if (EngineCI.AdapterId < Adapters.size())
+ hardwareAdapter = Adapters[EngineCI.AdapterId];
else
{
- LOG_ERROR_AND_THROW(EngineAttribs.AdapterId, " is not a valid hardware adapter id. Total number of compatible adapters available on this system: ", Adapters.size());
+ LOG_ERROR_AND_THROW(EngineCI.AdapterId, " is not a valid hardware adapter id. Total number of compatible adapters available on this system: ", Adapters.size());
}
}
@@ -199,7 +199,7 @@ void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attr
return;
}
- AttachToD3D11Device(pd3d11Device, pd3d11Context, EngineAttribs, ppDevice, ppContexts, NumDeferredContexts);
+ AttachToD3D11Device(pd3d11Device, pd3d11Context, EngineCI, ppDevice, ppContexts, NumDeferredContexts);
}
@@ -207,7 +207,7 @@ void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attr
/// \param [in] pd3d11NativeDevice - pointer to native D3D11 device
/// \param [in] pd3d11ImmediateContext - pointer to native D3D11 immediate context
/// \param [in] EngineAttribs - Engine creation attributes.
/// \param [out] ppDevice - Address of the memory location where pointer to
/// the created device will be written
/// \param [out] ppContexts - Address of the memory location where pointers to
@@ -218,15 +218,15 @@ void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attr
/// of deferred contexts is requested, pointers to the
/// contexts are written to ppContexts array starting
/// at position 1
-void EngineFactoryD3D11Impl::AttachToD3D11Device(void* pd3d11NativeDevice,
- void* pd3d11ImmediateContext,
- const EngineD3D11Attribs& EngineAttribs,
- IRenderDevice** ppDevice,
- IDeviceContext** ppContexts,
- Uint32 NumDeferredContexts)
+void EngineFactoryD3D11Impl::AttachToD3D11Device(void* pd3d11NativeDevice,
+ void* pd3d11ImmediateContext,
+ const EngineD3D11CreateInfo& EngineCI,
+ IRenderDevice** ppDevice,
+ IDeviceContext** ppContexts,
+ Uint32 NumDeferredContexts)
{
- if (EngineAttribs.DebugMessageCallback != nullptr)
- SetDebugMessageCallback(EngineAttribs.DebugMessageCallback);
+ if (EngineCI.DebugMessageCallback != nullptr)
+ SetDebugMessageCallback(EngineCI.DebugMessageCallback);
VERIFY( ppDevice && ppContexts, "Null pointer provided" );
if( !ppDevice || !ppContexts )
@@ -237,14 +237,14 @@ void EngineFactoryD3D11Impl::AttachToD3D11Device(void* pd3d1
ID3D11Device *pd3d11Device = reinterpret_cast<ID3D11Device *>(pd3d11NativeDevice);
ID3D11DeviceContext *pd3d11ImmediateCtx = reinterpret_cast<ID3D11DeviceContext *>(pd3d11ImmediateContext);
- SetRawAllocator(EngineAttribs.pRawMemAllocator);
+ SetRawAllocator(EngineCI.pRawMemAllocator);
auto &RawAlloctor = GetRawAllocator();
RenderDeviceD3D11Impl *pRenderDeviceD3D11(NEW_RC_OBJ(RawAlloctor, "RenderDeviceD3D11Impl instance", RenderDeviceD3D11Impl)
- (RawAlloctor, EngineAttribs, pd3d11Device, NumDeferredContexts));
+ (RawAlloctor, EngineCI, pd3d11Device, NumDeferredContexts));
pRenderDeviceD3D11->QueryInterface(IID_RenderDevice, reinterpret_cast<IObject**>(ppDevice));
RefCntAutoPtr<DeviceContextD3D11Impl> pDeviceContextD3D11(NEW_RC_OBJ(RawAlloctor, "DeviceContextD3D11Impl instance", DeviceContextD3D11Impl)
- (RawAlloctor, pRenderDeviceD3D11, pd3d11ImmediateCtx, EngineAttribs, false));
+ (RawAlloctor, pRenderDeviceD3D11, pd3d11ImmediateCtx, EngineCI, false));
// We must call AddRef() (implicitly through QueryInterface()) because pRenderDeviceD3D11 will
// keep a weak reference to the context
pDeviceContextD3D11->QueryInterface(IID_DeviceContext, reinterpret_cast<IObject**>(ppContexts));
@@ -257,7 +257,7 @@ void EngineFactoryD3D11Impl::AttachToD3D11Device(void* pd3d1
CHECK_D3D_RESULT_THROW(hr, "Failed to create D3D11 deferred context");
RefCntAutoPtr<DeviceContextD3D11Impl> pDeferredCtxD3D11(
NEW_RC_OBJ(RawAlloctor, "DeviceContextD3D11Impl instance", DeviceContextD3D11Impl)
- (RawAlloctor, pRenderDeviceD3D11, pd3d11DeferredCtx, EngineAttribs, true));
+ (RawAlloctor, pRenderDeviceD3D11, pd3d11DeferredCtx, EngineCI, true));
// We must call AddRef() (implicitly through QueryInterface()) because pRenderDeviceD3D12 will
// keep a weak reference to the context
pDeferredCtxD3D11->QueryInterface(IID_DeviceContext, reinterpret_cast<IObject**>(ppContexts + 1 + DeferredCtx));
@@ -299,12 +299,12 @@ void EngineFactoryD3D11Impl::AttachToD3D11Device(void* pd3d1
///
/// \param [out] ppSwapChain - Address of the memory location where pointer to the new
/// swap chain will be written
-void EngineFactoryD3D11Impl::CreateSwapChainD3D11( IRenderDevice* pDevice,
- IDeviceContext* pImmediateContext,
- const SwapChainDesc& SCDesc,
- const FullScreenModeDesc& FSDesc,
- void* pNativeWndHandle,
- ISwapChain** ppSwapChain )
+void EngineFactoryD3D11Impl::CreateSwapChainD3D11(IRenderDevice* pDevice,
+ IDeviceContext* pImmediateContext,
+ const SwapChainDesc& SCDesc,
+ const FullScreenModeDesc& FSDesc,
+ void* pNativeWndHandle,
+ ISwapChain** ppSwapChain)
{
VERIFY( ppSwapChain, "Null pointer provided" );
if( !ppSwapChain )
@@ -92,7 +92,7 @@ inline bool SdkLayersAvailable()
/// Creates render device and device contexts for Direct3D11-based engine implementation
-/// \param [in] EngineAttribs - Engine creation attributes.
+/// \param [in] EngineCI - Engine creation attributes.
/// \param [out] ppDevice - Address of the memory location where pointer to
/// the created device will be written
@@ -207,7 +207,7 @@ void EngineFactoryD3D11Impl::CreateDeviceAndContextsD3D11( const EngineD3D11Attr
/// \param [in] pd3d11NativeDevice - pointer to native D3D11 device
/// \param [in] pd3d11ImmediateContext - pointer to native D3D11 immediate context
-/// \param [in] EngineAttribs - Engine creation attributes.
+/// \param [in] EngineCI - Engine creation attributes.
/// \param [out] ppDevice - Address of the memory location where pointer to
/// the created device will be written